/**************************************************************************
 Copyright:
      (C) 2008 - 2011  Alexander Shaduri <ashaduri 'at' gmail.com>
 License: See LICENSE_zlib.txt file
***************************************************************************/

#ifndef LIBDEBUG_LIBDEBUG_H
#define LIBDEBUG_LIBDEBUG_H


// These macros may be used to control how libdebug is built:

// define ENABLE_GLIB to 1 to enable Glib option parsing support.
// define DEBUG_BUILD to enable all levels by default.



// all libdebug headers:

#include "dchannel.h"
#include "dcmdarg.h"
#include "dexcept.h"
#include "dflags.h"
#include "dout.h"
#include "dstate_pub.h"
// #include "dstream.h"  // no dstream - it's internal only



#endif
